cmoncrawl.common.types.ExtractorConfig — CmonCrawl 1.0.0 documentation

Toggle navigation sidebar
Toggle in-page Table of Contents

# cmoncrawl.common.types.ExtractorConfig

class cmoncrawl.common.types.ExtractorConfig(name: str, since: Optional[datetime] = None, to: Optional[datetime] = None)

  Configuration for extractor.

  __init__(name: str, since: Optional[datetime] = None, to: Optional[datetime] = None) → None

  Methods

  `__init__`(name[, since, to]) |
  `from_dict`(kvs, *[, infer_missing]) |
  `from_json`(s, *[, parse_float, parse_int, ...]) |
  `schema`(*[, infer_missing, only, exclude, ...]) |
  `to_dict`([encode_json]) |
  `to_json`(*[, skipkeys, ensure_ascii, ...]) |

  Attributes

  `since` |
  `to` |
  `name` |